@@ -1,4 +1,4 @@
-from . import logs, tracks, boto3_enhancer, model
+from . import logs, tracks, boto3_enhancer
 
 from ._version import get_versions
 __version__ = get_versions()['version']
